import { Link } from "react-router-dom";

interface CardProps {
	title: string;
	description: string;
	bgImage?: string;
	link: string;
}
/**
 * Card component
 * @param {string} title - Card title
 * @param {string} description - Card description
 * @param {string} bgImage - Background image
 * @param {string} link - Link to open on button click
 */
export function Card({ title, description, bgImage, link }: CardProps) {
	return (
		<div className="card min-w-[230px] bg-neutral text-neutral-content">
			{!!bgImage && (
				<figure>
					<img src={bgImage} alt={title + "_bgImage"} />
				</figure>
			)}
			<div className="card-body items-center text-center">
				<h2 className="card-title">{title}</h2>
				<p>{description}</p>
				<div className="card-actions justify-end">
					<Link to={link || "/"} className="btn btn-primary">
						Go
					</Link>
				</div>
			</div>
		</div>
	);
}
