import { useContext } from "react";
import { ConfirmationDialogContext, ConfirmationDialogContextType } from "../../contexts/ConfirmationDialogContext";

/**
 * @description Hook to manage the confirmation dialog, only passes the controls to specyfic dialog component
 * @param onConfirm Function to be called when the user confirms the action
 * @param onCancel Function to be called when the user cancels the action
 * @returns Hook controls
 */
export const useConfirmationDialog = (): ConfirmationDialogContextType => {
	const context = useContext(ConfirmationDialogContext);
	if (!context) {
		throw new Error("useConfirmationDialog must be used within a ConfirmationDialogProvider");
	}
	return context;
};

export default useConfirmationDialog;
