/* eslint-disable react-refresh/only-export-components */
import { Suspense, lazy } from "react";
import { RouteObject } from "react-router-dom";
import Loader from "./components/Loader";
import AboutPage from "./features/About/AboutPage";
import App from "./features/App/App";
import Debugger from "./features/Debugger";
import { flatternRoutingTable } from "./utils/RoutingTableUtils";
//----

const HomePageLazy = lazy(() => import("./features/Home/HomePage"));

export const viteEnv = import.meta.env;

// Based on https://reactrouter.com/en/main/start/overview#nested-routes with additional props
export const navigation: CustomRouteObject[] = [
	// root page, mainframe for all pages, skipped in navigation tree generation (inly childs are used)
	{
		path: "/",
		element: <App />,
		additionalProps: {
			name: "Root", // used for breadcrumbs and navigation tree
			disableRedirect: false, //entry will not be included in the react-router redirect list, will cut out childs
			disableInNavbar: true, //entry will not be rendered in the navbar
			disableBreadcrumbBar: false, //entry will be directly under root in routing table
		},
		children: [
			// home page
			{
				path: "/",
				index: true, //if true will be used as a default route for parent, dont declare path if use this
				element: (
					<Suspense fallback={<Loader />}>
						<HomePageLazy />
					</Suspense>
				),
				additionalProps: {
					name: "Home",
					disableRedirect: false,
					disableInNavbar: false,
					disableBreadcrumbBar: false,
				},
			},
			// about page
			{
				path: "about",
				element: <AboutPage />,
				additionalProps: {
					name: "About",
					disableRedirect: false,
					disableInNavbar: false,
					disableBreadcrumbBar: false,
				},
			},
		],
	},
];

if (viteEnv.DEV) {
	navigation[0].children!.push({
		path: "debug_variables",
		element: <Debugger />,
		additionalProps: {
			name: "Debug Variables",
			disableRedirect: false,
			disableInNavbar: false,
			disableBreadcrumbBar: false,
		},
	});
}

// ---
//Custom Route Object for handling custom behaviours on app navigation
export interface RouteObjectAdditionalProps {
	name: string;
	disableRedirect: boolean;
	disableInNavbar: boolean;
	disableBreadcrumbBar: boolean;
}
export interface CustomRouteObject extends Omit<RouteObject, "children"> {
	additionalProps: RouteObjectAdditionalProps;
	children?: CustomRouteObject[];
}
//----
//Main configuration, static data, mostly used here
export const main = {
	program_name: viteEnv.VITE_APP_NAME,
	program_version: "2.0.0",
};
//About page configuration
export const about = {
	program_description: `${main.program_name} to nowoczesna platforma dedykowana specjalistom z branży obróbki skrawaniem. Nasza strona umożliwia profesjonalny dobór narzędzi do frezowania, gwarantując precyzję i efektywność w każdym projekcie. Dzięki intuicyjnemu interfejsowi i zaawansowanym algorytmom, ${main.program_name} staje się niezastąpionym narzędziem dla każdego, kto chce osiągnąć perfekcyjne rezultaty w obróbce materiałów.`,
	program_authors: [{ name: "Bartosz Bielski", email: "bartbie194@student.polsl.pl" }],
};
//----
export const flatRoutes = flatternRoutingTable(navigation);
